#!/bin/sh
#
#	This file is executed by init(8) when the system is being
#	initialized for one of the "multi user" run levels (i.e.
#	levels 1 through 6).  
#
# /etc/rc.d/rc.M (12-15-99) Linux

# Tell the viewers what's going to happen:
echo "Going multiuser..."

# Screen blanks after 0-60 minutes idle time.
# To turn speaker beep off: -bfreq 0

if [ -x /bin/setterm ]; then
/bin/setterm -blank 60 -powersave on   
fi

# Look for a CD-ROM in a CD-ROM drive, if one is found
# mount it under /mnt/cdrom.

#if [ -x /etc/rc.d/rc.cdrom ]; then
# /etc/rc.d/rc.cdrom
#fi

# If there's no /etc/HOSTNAME, fall back on this default:

if [ ! -s /etc/HOSTNAME ]; then
echo "Linux" > /etc/HOSTNAME
fi

# Set the hostname from the /etc/HOSTNAME file. 

if [ -x /bin/hostname ]; then
/bin/hostname `cat /etc/HOSTNAME | cut -f1 -d .`
fi

# Initialize the NET subsystem.

if [ -x /etc/rc.d/rc.inet1 ]; then
  . /etc/rc.d/rc.inet1
fi

if [ -x /etc/rc.d/rc.inet2 ]; then
  . /etc/rc.d/rc.inet2
else

  if [ -x /usr/sbin/syslogd ]; then
  echo "Starting system log daemon: syslogd"
  /usr/sbin/syslogd -m 0  
    sleep 1 # Prevents a race condition with SMP kernels
            # '-c 3' displays level 'error' or higher messages on the console
#echo "Starting kernel log daemon: klogd"
#/usr/sbin/klogd -c 3 
  fi

# Start printer daemon:

if [ -x /usr/sbin/lpd ]; then
echo "Starting printer daemon: lpd"
/usr/sbin/lpd
fi
fi

# Start netatalk. (a file/print server for Macs using Appletalk)

#if [ -x /etc/rc.d/rc.atalk ]; then
#  /etc/rc.d/rc.atalk
#fi

# Start crond (Dillon's crond):
# If you want cron to actually log activity to /var/adm/cron, then change
# -l10 to -l8 to increase the logging level.

#if [ -x /usr/sbin/crond ]; then
#/usr/sbin/crond -l10 >>/var/adm/cron 2>&1
#fi

# Start atd (manages jobs scheduled with 'at'):

#if [ -x /usr/sbin/atd ]; then
#/usr/sbin/atd -b 15 -l 1
#fi

# Remove stale files (must be done after mount -a!)
rm -f /var/lock/LCK* /var/spool/uucp/LCK*    
rm -rf 2>/dev/null /tmp/.* /tmp/* /var/tmp/.* /var/tmp/* 

# Create /tmp directory if it doesn't exist.

if [ ! -d /tmp ]; then
mkdir /tmp
fi

# Ensure basic filesystem permissions sanity.

chmod 755 / 2>/dev/null
chmod 1777 /tmp /var/tmp 2>/dev/null

# Update all the shared library links automatically
/sbin/ldconfig -q

# Slackware-Mini-Quota-HOWTO:
# To really activate quotas, you'll need to add 'usrquota' to the appropriate
# partitions as listed in /etc/fstab.  Here's an example:
# /dev/hda2   /home   ext2   defaults,usrquota    1   1
# You'll then need to setup initial quota files at the top of the partitions
# to support quota, like this:
# touch /home/quota.user /home/quota.group
# chmod 600 /home/quota.user /home/quota.group
# Then, reboot to activate the system.
# To edit user quotas, use 'edquota'.  See 'man edquota'.  Also, the
# official Quota Mini-HOWTO has lots of useful information.  That can be found
# here:  ftp://ftp.cdrom.com/pub/linux/slackware/docs/mini/Quota

# Check quotas and then turn quota system on:
if grep -F quota /etc/fstab 1> /dev/null 2> /dev/null ; then
  if [ -x /sbin/quotacheck ]; then
    echo "Checking filesystem quotas..."
    /sbin/quotacheck -avug
  fi
  if [ -x /sbin/quotaon ]; then
    echo "Activating filesystem quotas..."
    /sbin/quotaon -avug
  fi
fi

# Start the sendmail daemon:

if [ -x /usr/sbin/sendmail ]; then
  echo "Starting sendmail daemon: sendmail -bd -q15m"
  /usr/sbin/sendmail -bd -q15m
fi

# Start APM daemon 'apmd' for laptop computers.

if [ -f /proc/apm -a -x /usr/sbin/apmd ]; then
echo "Starting apm daemon: apmd"
/usr/sbin/apmd
fi

# Load a custom screen font if the user has an rc.font script.
if [ -x /etc/rc.d/rc.font ]; then
  . /etc/rc.d/rc.font
fi

# Load a custom keymap if the user has an rc.keymap script.
if [ -x /etc/rc.d/rc.keymap ]; then
  . /etc/rc.d/rc.keymap
fi

# iBCS Emulation for Linux
# The Intel Binary Compatibility Specification, or iBCS, specifies the
# interfaces between application programs and the surrounding operating
# system environment for i386 based systems. There are however several
# flavours of iBCS in use - SVR4, SVR3 plus several vendor specific
# extensions to SVR3 which are slightly different and incompatible. The
# iBCS emulator for Linux supports all flavours known so far.
if [ -x /etc/rc.d/rc.ibcs2 ]; then
  . /etc/rc.d/rc.ibcs2
fi

# Start Web server:
if [ -x /etc/rc.d/rc.httpd ]; then
  . /etc/rc.d/rc.httpd
fi

# Start Samba (a file/print server for Win95/NT machines):
if [ -x /etc/rc.d/rc.samba ]; then
  . /etc/rc.d/rc.samba
fi

# Start GPM mouse driver.
# If you have a ps2 mouse put: -t ps2

#if [ -x /usr/bin/gpm ]; then
#echo "Starting mouse driver: gpm"
#/usr/bin/gpm -t mman
#fi

# If there are SystemV init scripts for this runlevel, run them.
if [ -x /etc/rc.d/rc.sysvinit ]; then
  . /etc/rc.d/rc.sysvinit
fi

# Start the local setup procedure.

if [ -x /etc/rc.d/rc.local ]; then
 . /etc/rc.d/rc.local
fi

# All done.
